Exceptions
===================================

.. currentmodule:: chemcoord

.. autosummary::
    :toctree: src_exceptions

    ~exceptions.InvalidReference
    ~exceptions.UndefinedCoordinateSystem
    ~exceptions.IllegalArgumentCombination
    ~exceptions.PhysicalMeaning
